// set this to true, to clearCookies when the tab icon is clicked once for all flagged tags, there is a "one" time change to unflag them from deletion
var useActiveClearing = true;

// Shouldnt be required to make changes from here???
var domainURL = ""; // The active domain url

//---------------------------------------------------------------------------------------------------------------------------------

async function flagSwitch(event) {
  let data = await browser.storage.local.get();
  let cookieName = event.target.dataset['cookieName'];

  if (data[domainURL] === undefined) {
    data[domainURL] = {};
  }

  if (data[domainURL][cookieName]) {
    delete data[domainURL][cookieName];
    event.target.className = "";
  } else {
    data[domainURL][cookieName] = true;
    event.target.className = "flagged";
  }

  await browser.storage.local.set(data);
}

async function showCookiesForTab(tabs) {
  //get the first tab object in the array
  let tab = tabs.pop();
  let data = await browser.storage.local.get();

  domainURL = tab.url.match(/(http|https):\/\/[a-zA-Z0-9öäüÖÄÜ\.\-\:]*\//)[0];
  
  //get all cookies in the domain
  var gettingAllCookies = browser.cookies.getAll({url: domainURL});
  gettingAllCookies.then((cookies) => {

    //set the header of the panel
    var activeTabUrl = document.querySelector("#header-title");
    var text = document.createTextNode("Cookies: "+domainURL);
    var cookieList = document.getElementById('cookie-list');
    activeTabUrl.appendChild(text);

    if (cookies.length > 0) {
      for (let cookie of cookies) {
        let li = document.createElement("li");

        let btn = document.createElement("button");
        let btnContent = document.createTextNode("Flag");
        btn.appendChild(btnContent);
        btn.addEventListener("click", flagSwitch);
        btn.dataset['cookieName'] = cookie.name;

        if (data[domainURL] !== undefined && data[domainURL][cookie.name]) {
          btn.className = "flagged";
        }

        let p = document.createElement("p");

        let pcontent = document.createTextNode(cookie.name + ": "+ cookie.value);
        p.appendChild(pcontent);

        li.appendChild(btn);
        li.appendChild(p);

        cookieList.appendChild(li);
      }
    } else {
      let p = document.createElement("p");
      let content = document.createTextNode("No cookies in this tab.");
      let parent = cookieList.parentNode;

      p.appendChild(content);
      parent.appendChild(p);
    }
  });

  if (useActiveClearing) {
    clearCookies();
  }
}

function getActiveTab() {
  return browser.tabs.query({currentWindow: true, active: true});
}

//---------------------------------------------------------------------------------------------------------------------------------

async function clearCookies() {
  let data = await browser.storage.local.get();

  if (data[domainURL] !== undefined) {
    for (let cookie in data[domainURL]) {
      let details = { url: domainURL, name: cookie };
      browser.cookies.remove(details);
    }
  }
}

//---------------------------------------------------------------------------------------------------------------------------------

function clearCookiesOnUpdate(tabId, changeInfo, tabInfo) {
  clearCookies();
}

function clearCookiesOnLeave(tabId, moveInfo) {
  clearCookies();
}

async function setdomainURLOnActivation(activeInfo) {
  var currentTab = await browser.tabs.getCurrent();
  if (currentTab.url) {
    let urlMatch = currentTab.url.match(/(http|https):\/\/[a-zA-Z0-9öäüÖÄÜ\.\-\:]*\//);
    if (match[0] !== undefined) {
      domainURL = match[0];
    }
  }
}

browser.tabs.onRemoved.addListener(clearCookiesOnLeave);
browser.tabs.onUpdated.addListener(clearCookiesOnUpdate);
browser.tabs.onActivated.addListener(setdomainURLOnActivation);

//---------------------------------------------------------------------------------------------------------------------------------

getActiveTab().then(showCookiesForTab);
